@@ -53,6 +53,7 @@ class Voicebox(VoiceboxBase, VoiceConnection):
         self.__is_alive = True
         self.__shard_id = shard_id
         self.__owner = owner
+        self.__on_close = on_close
 
         return self
 
@@ -85,6 +86,7 @@ class Voicebox(VoiceboxBase, VoiceConnection):
         """Signal the process to shut down."""
         self.__is_alive = False
         await self.driver.leave()
+        await self.__on_close(self)
 
     async def join(self) -> None:
         """Wait for the process to halt before continuing."""
